@@ -1,13 +1,37 @@
-#[doc = "Reader of register CONFIG1"]
-pub type R = crate::R<u32, super::CONFIG1>;
-#[doc = "Writer for register CONFIG1"]
-pub type W = crate::W<u32, super::CONFIG1>;
-#[doc = "Register CONFIG1 `reset()`'s with value 0"]
-impl crate::ResetValue for super::CONFIG1 {
-    type Type = u32;
+#[doc = "Register `CONFIG1` reader"]
+pub struct R(crate::R<CONFIG1_SPEC>);
+impl core::ops::Deref for R {
+    type Target = crate::R<CONFIG1_SPEC>;
     #[inline(always)]
-    fn reset_value() -> Self::Type {
-        0
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+impl From<crate::R<CONFIG1_SPEC>> for R {
+    #[inline(always)]
+    fn from(reader: crate::R<CONFIG1_SPEC>) -> Self {
+        R(reader)
+    }
+}
+#[doc = "Register `CONFIG1` writer"]
+pub struct W(crate::W<CONFIG1_SPEC>);
+impl core::ops::Deref for W {
+    type Target = crate::W<CONFIG1_SPEC>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+impl core::ops::DerefMut for W {
+    #[inline(always)]
+    fn deref_mut(&mut self) -> &mut Self::Target {
+        &mut self.0
+    }
+}
+impl From<crate::W<CONFIG1_SPEC>> for W {
+    #[inline(always)]
+    fn from(writer: crate::W<CONFIG1_SPEC>) -> Self {
+        W(writer)
     }
 }
 #[doc = "Enable protection for region 32. Write '0' has no effect.\n\nValue on reset: 0"]
@@ -24,9 +48,12 @@ impl From<REGION32_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `REGION32`"]
-pub type REGION32_R = crate::R<bool, REGION32_A>;
+#[doc = "Field `REGION32` reader - Enable protection for region 32. Write '0' has no effect."]
+pub struct REGION32_R(crate::FieldReader<bool, REGION32_A>);
 impl REGION32_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        REGION32_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> REGION32_A {
@@ -38,15 +65,22 @@ impl REGION32_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == REGION32_A::DISABLED
+        **self == REGION32_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == REGION32_A::ENABLED
+        **self == REGION32_A::ENABLED
     }
 }
-#[doc = "Write proxy for field `REGION32`"]
+impl core::ops::Deref for REGION32_R {
+    type Target = crate::FieldReader<bool, REGION32_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `REGION32` writer - Enable protection for region 32. Write '0' has no effect."]
 pub struct REGION32_W<'a> {
     w: &'a mut W,
 }
@@ -54,9 +88,7 @@ impl<'a> REGION32_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: REGION32_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Protection disabled"]
     #[inline(always)]
@@ -81,7 +113,7 @@ impl<'a> REGION32_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | ((value as u32) & 0x01);
+        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
         self.w
     }
 }
@@ -99,9 +131,12 @@ impl From<REGION33_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `REGION33`"]
-pub type REGION33_R = crate::R<bool, REGION33_A>;
+#[doc = "Field `REGION33` reader - Enable protection for region 33. Write '0' has no effect."]
+pub struct REGION33_R(crate::FieldReader<bool, REGION33_A>);
 impl REGION33_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        REGION33_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> REGION33_A {
@@ -113,15 +148,22 @@ impl REGION33_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == REGION33_A::DISABLED
+        **self == REGION33_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == REGION33_A::ENABLED
+        **self == REGION33_A::ENABLED
     }
 }
-#[doc = "Write proxy for field `REGION33`"]
+impl core::ops::Deref for REGION33_R {
+    type Target = crate::FieldReader<bool, REGION33_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `REGION33` writer - Enable protection for region 33. Write '0' has no effect."]
 pub struct REGION33_W<'a> {
     w: &'a mut W,
 }
@@ -129,9 +171,7 @@ impl<'a> REGION33_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: REGION33_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Protection disabled"]
     #[inline(always)]
@@ -156,7 +196,7 @@ impl<'a> REGION33_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | (((value as u32) & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
         self.w
     }
 }
@@ -174,9 +214,12 @@ impl From<REGION34_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `REGION34`"]
-pub type REGION34_R = crate::R<bool, REGION34_A>;
+#[doc = "Field `REGION34` reader - Enable protection for region 34. Write '0' has no effect."]
+pub struct REGION34_R(crate::FieldReader<bool, REGION34_A>);
 impl REGION34_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        REGION34_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> REGION34_A {
@@ -188,15 +231,22 @@ impl REGION34_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == REGION34_A::DISABLED
+        **self == REGION34_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == REGION34_A::ENABLED
+        **self == REGION34_A::ENABLED
     }
 }
-#[doc = "Write proxy for field `REGION34`"]
+impl core::ops::Deref for REGION34_R {
+    type Target = crate::FieldReader<bool, REGION34_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `REGION34` writer - Enable protection for region 34. Write '0' has no effect."]
 pub struct REGION34_W<'a> {
     w: &'a mut W,
 }
@@ -204,9 +254,7 @@ impl<'a> REGION34_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: REGION34_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Protection disabled"]
     #[inline(always)]
@@ -231,7 +279,7 @@ impl<'a> REGION34_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | (((value as u32) & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
         self.w
     }
 }
@@ -249,9 +297,12 @@ impl From<REGION35_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `REGION35`"]
-pub type REGION35_R = crate::R<bool, REGION35_A>;
+#[doc = "Field `REGION35` reader - Enable protection for region 35. Write '0' has no effect."]
+pub struct REGION35_R(crate::FieldReader<bool, REGION35_A>);
 impl REGION35_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        REGION35_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> REGION35_A {
@@ -263,15 +314,22 @@ impl REGION35_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == REGION35_A::DISABLED
+        **self == REGION35_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == REGION35_A::ENABLED
+        **self == REGION35_A::ENABLED
     }
 }
-#[doc = "Write proxy for field `REGION35`"]
+impl core::ops::Deref for REGION35_R {
+    type Target = crate::FieldReader<bool, REGION35_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `REGION35` writer - Enable protection for region 35. Write '0' has no effect."]
 pub struct REGION35_W<'a> {
     w: &'a mut W,
 }
@@ -279,9 +337,7 @@ impl<'a> REGION35_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: REGION35_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Protection disabled"]
     #[inline(always)]
@@ -306,7 +362,7 @@ impl<'a> REGION35_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | (((value as u32) & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
         self.w
     }
 }
@@ -324,9 +380,12 @@ impl From<REGION36_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `REGION36`"]
-pub type REGION36_R = crate::R<bool, REGION36_A>;
+#[doc = "Field `REGION36` reader - Enable protection for region 36. Write '0' has no effect."]
+pub struct REGION36_R(crate::FieldReader<bool, REGION36_A>);
 impl REGION36_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        REGION36_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> REGION36_A {
@@ -338,15 +397,22 @@ impl REGION36_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == REGION36_A::DISABLED
+        **self == REGION36_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == REGION36_A::ENABLED
+        **self == REGION36_A::ENABLED
     }
 }
-#[doc = "Write proxy for field `REGION36`"]
+impl core::ops::Deref for REGION36_R {
+    type Target = crate::FieldReader<bool, REGION36_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `REGION36` writer - Enable protection for region 36. Write '0' has no effect."]
 pub struct REGION36_W<'a> {
     w: &'a mut W,
 }
@@ -354,9 +420,7 @@ impl<'a> REGION36_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: REGION36_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Protection disabled"]
     #[inline(always)]
@@ -381,7 +445,7 @@ impl<'a> REGION36_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | (((value as u32) & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
         self.w
     }
 }
@@ -399,9 +463,12 @@ impl From<REGION37_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `REGION37`"]
-pub type REGION37_R = crate::R<bool, REGION37_A>;
+#[doc = "Field `REGION37` reader - Enable protection for region 37. Write '0' has no effect."]
+pub struct REGION37_R(crate::FieldReader<bool, REGION37_A>);
 impl REGION37_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        REGION37_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> REGION37_A {
@@ -413,15 +480,22 @@ impl REGION37_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == REGION37_A::DISABLED
+        **self == REGION37_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == REGION37_A::ENABLED
+        **self == REGION37_A::ENABLED
     }
 }
-#[doc = "Write proxy for field `REGION37`"]
+impl core::ops::Deref for REGION37_R {
+    type Target = crate::FieldReader<bool, REGION37_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `REGION37` writer - Enable protection for region 37. Write '0' has no effect."]
 pub struct REGION37_W<'a> {
     w: &'a mut W,
 }
@@ -429,9 +503,7 @@ impl<'a> REGION37_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: REGION37_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Protection disabled"]
     #[inline(always)]
@@ -456,7 +528,7 @@ impl<'a> REGION37_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | (((value as u32) & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
         self.w
     }
 }
@@ -474,9 +546,12 @@ impl From<REGION38_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `REGION38`"]
-pub type REGION38_R = crate::R<bool, REGION38_A>;
+#[doc = "Field `REGION38` reader - Enable protection for region 38. Write '0' has no effect."]
+pub struct REGION38_R(crate::FieldReader<bool, REGION38_A>);
 impl REGION38_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        REGION38_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> REGION38_A {
@@ -488,15 +563,22 @@ impl REGION38_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == REGION38_A::DISABLED
+        **self == REGION38_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == REGION38_A::ENABLED
+        **self == REGION38_A::ENABLED
     }
 }
-#[doc = "Write proxy for field `REGION38`"]
+impl core::ops::Deref for REGION38_R {
+    type Target = crate::FieldReader<bool, REGION38_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `REGION38` writer - Enable protection for region 38. Write '0' has no effect."]
 pub struct REGION38_W<'a> {
     w: &'a mut W,
 }
@@ -504,9 +586,7 @@ impl<'a> REGION38_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: REGION38_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Protection disabled"]
     #[inline(always)]
@@ -531,7 +611,7 @@ impl<'a> REGION38_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | (((value as u32) & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
         self.w
     }
 }
@@ -549,9 +629,12 @@ impl From<REGION39_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `REGION39`"]
-pub type REGION39_R = crate::R<bool, REGION39_A>;
+#[doc = "Field `REGION39` reader - Enable protection for region 39. Write '0' has no effect."]
+pub struct REGION39_R(crate::FieldReader<bool, REGION39_A>);
 impl REGION39_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        REGION39_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> REGION39_A {
@@ -563,15 +646,22 @@ impl REGION39_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == REGION39_A::DISABLED
+        **self == REGION39_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == REGION39_A::ENABLED
+        **self == REGION39_A::ENABLED
     }
 }
-#[doc = "Write proxy for field `REGION39`"]
+impl core::ops::Deref for REGION39_R {
+    type Target = crate::FieldReader<bool, REGION39_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `REGION39` writer - Enable protection for region 39. Write '0' has no effect."]
 pub struct REGION39_W<'a> {
     w: &'a mut W,
 }
@@ -579,9 +669,7 @@ impl<'a> REGION39_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: REGION39_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Protection disabled"]
     #[inline(always)]
@@ -606,7 +694,7 @@ impl<'a> REGION39_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | (((value as u32) & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
         self.w
     }
 }
@@ -624,9 +712,12 @@ impl From<REGION40_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `REGION40`"]
-pub type REGION40_R = crate::R<bool, REGION40_A>;
+#[doc = "Field `REGION40` reader - Enable protection for region 40. Write '0' has no effect."]
+pub struct REGION40_R(crate::FieldReader<bool, REGION40_A>);
 impl REGION40_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        REGION40_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> REGION40_A {
@@ -638,15 +729,22 @@ impl REGION40_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == REGION40_A::DISABLED
+        **self == REGION40_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == REGION40_A::ENABLED
+        **self == REGION40_A::ENABLED
     }
 }
-#[doc = "Write proxy for field `REGION40`"]
+impl core::ops::Deref for REGION40_R {
+    type Target = crate::FieldReader<bool, REGION40_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `REGION40` writer - Enable protection for region 40. Write '0' has no effect."]
 pub struct REGION40_W<'a> {
     w: &'a mut W,
 }
@@ -654,9 +752,7 @@ impl<'a> REGION40_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: REGION40_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Protection disabled"]
     #[inline(always)]
@@ -681,7 +777,7 @@ impl<'a> REGION40_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | (((value as u32) & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
         self.w
     }
 }
@@ -699,9 +795,12 @@ impl From<REGION41_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `REGION41`"]
-pub type REGION41_R = crate::R<bool, REGION41_A>;
+#[doc = "Field `REGION41` reader - Enable protection for region 41. Write '0' has no effect."]
+pub struct REGION41_R(crate::FieldReader<bool, REGION41_A>);
 impl REGION41_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        REGION41_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> REGION41_A {
@@ -713,15 +812,22 @@ impl REGION41_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == REGION41_A::DISABLED
+        **self == REGION41_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == REGION41_A::ENABLED
+        **self == REGION41_A::ENABLED
     }
 }
-#[doc = "Write proxy for field `REGION41`"]
+impl core::ops::Deref for REGION41_R {
+    type Target = crate::FieldReader<bool, REGION41_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `REGION41` writer - Enable protection for region 41. Write '0' has no effect."]
 pub struct REGION41_W<'a> {
     w: &'a mut W,
 }
@@ -729,9 +835,7 @@ impl<'a> REGION41_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: REGION41_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Protection disabled"]
     #[inline(always)]
@@ -756,7 +860,7 @@ impl<'a> REGION41_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 9)) | (((value as u32) & 0x01) << 9);
+        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
         self.w
     }
 }
@@ -774,9 +878,12 @@ impl From<REGION42_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `REGION42`"]
-pub type REGION42_R = crate::R<bool, REGION42_A>;
+#[doc = "Field `REGION42` reader - Enable protection for region 42. Write '0' has no effect."]
+pub struct REGION42_R(crate::FieldReader<bool, REGION42_A>);
 impl REGION42_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        REGION42_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> REGION42_A {
@@ -788,15 +895,22 @@ impl REGION42_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == REGION42_A::DISABLED
+        **self == REGION42_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == REGION42_A::ENABLED
+        **self == REGION42_A::ENABLED
     }
 }
-#[doc = "Write proxy for field `REGION42`"]
+impl core::ops::Deref for REGION42_R {
+    type Target = crate::FieldReader<bool, REGION42_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `REGION42` writer - Enable protection for region 42. Write '0' has no effect."]
 pub struct REGION42_W<'a> {
     w: &'a mut W,
 }
@@ -804,9 +918,7 @@ impl<'a> REGION42_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: REGION42_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Protection disabled"]
     #[inline(always)]
@@ -831,7 +943,7 @@ impl<'a> REGION42_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 10)) | (((value as u32) & 0x01) << 10);
+        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
         self.w
     }
 }
@@ -849,9 +961,12 @@ impl From<REGION43_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `REGION43`"]
-pub type REGION43_R = crate::R<bool, REGION43_A>;
+#[doc = "Field `REGION43` reader - Enable protection for region 43. Write '0' has no effect."]
+pub struct REGION43_R(crate::FieldReader<bool, REGION43_A>);
 impl REGION43_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        REGION43_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> REGION43_A {
@@ -863,15 +978,22 @@ impl REGION43_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == REGION43_A::DISABLED
+        **self == REGION43_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == REGION43_A::ENABLED
+        **self == REGION43_A::ENABLED
     }
 }
-#[doc = "Write proxy for field `REGION43`"]
+impl core::ops::Deref for REGION43_R {
+    type Target = crate::FieldReader<bool, REGION43_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `REGION43` writer - Enable protection for region 43. Write '0' has no effect."]
 pub struct REGION43_W<'a> {
     w: &'a mut W,
 }
@@ -879,9 +1001,7 @@ impl<'a> REGION43_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: REGION43_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Protection disabled"]
     #[inline(always)]
@@ -906,7 +1026,7 @@ impl<'a> REGION43_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 11)) | (((value as u32) & 0x01) << 11);
+        self.w.bits = (self.w.bits & !(0x01 << 11)) | ((value as u32 & 0x01) << 11);
         self.w
     }
 }
@@ -924,9 +1044,12 @@ impl From<REGION44_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `REGION44`"]
-pub type REGION44_R = crate::R<bool, REGION44_A>;
+#[doc = "Field `REGION44` reader - Enable protection for region 44. Write '0' has no effect."]
+pub struct REGION44_R(crate::FieldReader<bool, REGION44_A>);
 impl REGION44_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        REGION44_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> REGION44_A {
@@ -938,15 +1061,22 @@ impl REGION44_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == REGION44_A::DISABLED
+        **self == REGION44_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == REGION44_A::ENABLED
+        **self == REGION44_A::ENABLED
     }
 }
-#[doc = "Write proxy for field `REGION44`"]
+impl core::ops::Deref for REGION44_R {
+    type Target = crate::FieldReader<bool, REGION44_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `REGION44` writer - Enable protection for region 44. Write '0' has no effect."]
 pub struct REGION44_W<'a> {
     w: &'a mut W,
 }
@@ -954,9 +1084,7 @@ impl<'a> REGION44_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: REGION44_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Protection disabled"]
     #[inline(always)]
@@ -981,7 +1109,7 @@ impl<'a> REGION44_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 12)) | (((value as u32) & 0x01) << 12);
+        self.w.bits = (self.w.bits & !(0x01 << 12)) | ((value as u32 & 0x01) << 12);
         self.w
     }
 }
@@ -999,9 +1127,12 @@ impl From<REGION45_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `REGION45`"]
-pub type REGION45_R = crate::R<bool, REGION45_A>;
+#[doc = "Field `REGION45` reader - Enable protection for region 45. Write '0' has no effect."]
+pub struct REGION45_R(crate::FieldReader<bool, REGION45_A>);
 impl REGION45_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        REGION45_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> REGION45_A {
@@ -1013,15 +1144,22 @@ impl REGION45_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == REGION45_A::DISABLED
+        **self == REGION45_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == REGION45_A::ENABLED
+        **self == REGION45_A::ENABLED
     }
 }
-#[doc = "Write proxy for field `REGION45`"]
+impl core::ops::Deref for REGION45_R {
+    type Target = crate::FieldReader<bool, REGION45_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `REGION45` writer - Enable protection for region 45. Write '0' has no effect."]
 pub struct REGION45_W<'a> {
     w: &'a mut W,
 }
@@ -1029,9 +1167,7 @@ impl<'a> REGION45_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: REGION45_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Protection disabled"]
     #[inline(always)]
@@ -1056,7 +1192,7 @@ impl<'a> REGION45_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 13)) | (((value as u32) & 0x01) << 13);
+        self.w.bits = (self.w.bits & !(0x01 << 13)) | ((value as u32 & 0x01) << 13);
         self.w
     }
 }
@@ -1074,9 +1210,12 @@ impl From<REGION46_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `REGION46`"]
-pub type REGION46_R = crate::R<bool, REGION46_A>;
+#[doc = "Field `REGION46` reader - Enable protection for region 46. Write '0' has no effect."]
+pub struct REGION46_R(crate::FieldReader<bool, REGION46_A>);
 impl REGION46_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        REGION46_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> REGION46_A {
@@ -1088,15 +1227,22 @@ impl REGION46_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == REGION46_A::DISABLED
+        **self == REGION46_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == REGION46_A::ENABLED
+        **self == REGION46_A::ENABLED
     }
 }
-#[doc = "Write proxy for field `REGION46`"]
+impl core::ops::Deref for REGION46_R {
+    type Target = crate::FieldReader<bool, REGION46_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `REGION46` writer - Enable protection for region 46. Write '0' has no effect."]
 pub struct REGION46_W<'a> {
     w: &'a mut W,
 }
@@ -1104,9 +1250,7 @@ impl<'a> REGION46_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: REGION46_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Protection disabled"]
     #[inline(always)]
@@ -1131,7 +1275,7 @@ impl<'a> REGION46_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 14)) | (((value as u32) & 0x01) << 14);
+        self.w.bits = (self.w.bits & !(0x01 << 14)) | ((value as u32 & 0x01) << 14);
         self.w
     }
 }
@@ -1149,9 +1293,12 @@ impl From<REGION47_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `REGION47`"]
-pub type REGION47_R = crate::R<bool, REGION47_A>;
+#[doc = "Field `REGION47` reader - Enable protection for region 47. Write '0' has no effect."]
+pub struct REGION47_R(crate::FieldReader<bool, REGION47_A>);
 impl REGION47_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        REGION47_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> REGION47_A {
@@ -1163,15 +1310,22 @@ impl REGION47_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == REGION47_A::DISABLED
+        **self == REGION47_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == REGION47_A::ENABLED
+        **self == REGION47_A::ENABLED
     }
 }
-#[doc = "Write proxy for field `REGION47`"]
+impl core::ops::Deref for REGION47_R {
+    type Target = crate::FieldReader<bool, REGION47_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `REGION47` writer - Enable protection for region 47. Write '0' has no effect."]
 pub struct REGION47_W<'a> {
     w: &'a mut W,
 }
@@ -1179,9 +1333,7 @@ impl<'a> REGION47_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: REGION47_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Protection disabled"]
     #[inline(always)]
@@ -1206,7 +1358,7 @@ impl<'a> REGION47_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 15)) | (((value as u32) & 0x01) << 15);
+        self.w.bits = (self.w.bits & !(0x01 << 15)) | ((value as u32 & 0x01) << 15);
         self.w
     }
 }
@@ -1373,4 +1525,30 @@ impl W {
     pub fn region47(&mut self) -> REGION47_W {
         REGION47_W { w: self }
     }
+    #[doc = "Writes raw bits to the register."]
+    #[inline(always)]
+    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
+        self.0.bits(bits);
+        self
+    }
+}
+#[doc = "Block protect configuration register 1\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [config1](index.html) module"]
+pub struct CONFIG1_SPEC;
+impl crate::RegisterSpec for CONFIG1_SPEC {
+    type Ux = u32;
+}
+#[doc = "`read()` method returns [config1::R](R) reader structure"]
+impl crate::Readable for CONFIG1_SPEC {
+    type Reader = R;
+}
+#[doc = "`write(|w| ..)` method takes [config1::W](W) writer structure"]
+impl crate::Writable for CONFIG1_SPEC {
+    type Writer = W;
+}
+#[doc = "`reset()` method sets CONFIG1 to value 0"]
+impl crate::Resettable for CONFIG1_SPEC {
+    #[inline(always)]
+    fn reset_value() -> Self::Ux {
+        0
+    }
 }
